package org.springblade.modules.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.apache.ibatis.annotations.Param;
import org.springblade.modules.entity.CyryEntity;
import org.springblade.modules.entity.SyryEntity;
import org.springblade.modules.vo.*;

import java.util.List;
import java.util.Map;

public interface SyryMapper extends BaseMapper<SyryEntity> {
	List<SyryEntity> getFwry(IPage<SyryEntity> page, @Param("params") Map<String, Object> params);

	String getFwxzByRkDzxx(String dzbm);

	CzrkVO fwryCzrkDetail(SyryEntity syryEntity);

	JwrkVO fwryJwrkDetail(SyryEntity syryEntity);

	JzrkVO fwryJzrkDetail(SyryEntity syryEntity);

	WlrkVO fwryWlrkDetail(SyryEntity syryEntity);

	ZzrkVO fwryZzrkDetail(SyryEntity syryEntity);

	String selectDictBiz(String tsrq);

	UserVO djxx(Long id);

	void updateFwId(@Param("fwId") Long fwId, @Param("dzbm") String dzbm, @Param("ryType") String ryType, @Param("ryId") Long ryId);

	CzrkVO cyryCzrkDetail(String gmsfhm);

	JwrkVO cyryJwrkDetail(String gmsfhm);

	JzrkVO cyryJzrkDetail(String gmsfhm);

	WlrkVO cyryWlrkDetail(String gmsfhm);

	ZzrkVO cyryZzrkDetail(String gmsfhm);

	CzrkVO cyrylsCzrkDetail(String gmsfhm, String dzbm);

	JwrkVO cyrylsJwrkDetail(String gmsfhm, String dzbm);

	JzrkVO cyrylsJzrkDetail(String gmsfhm, String dzbm);

	WlrkVO cyrylsWlrkDetail(String gmsfhm, String dzbm);

	ZzrkVO cyrylsZzrkDetail(String gmsfhm, String dzbm);

	CyryEntity cyryDetail(String gmsfhm);

	List<SyryEntity> getMphxlhByLdphxlh(Map<String, Object> params);

	SyryEntity selectFwInfo(@Param("params") Map<String, Object> params, String dzbm);
}
